@@ -5,10 +5,10 @@ lossMapping <- c("binder.draws" = 0L, "binder.psm" = 1L, "omARI" = 2L,
                  "NVI" = 6L, "ID" = 7L, "NID" = 8L)
 
 isPSM <- function(x) {
-  ( isSymmetric(x) && all(0 <= x) && all(x <= 1) && all(diag(x)==1) )
+  is.matrix(x) && isSymmetric(x) && all(0 <= x) && all(x <= 1) && all(diag(x)==1)
 }
 
-x2drawspsm <- function(x, loss, nCores=0) {
+x2drawspsm <- function(x, loss, nCores=0, forceNotPSM=TRUE) {
   draws <- NULL
   psm <- NULL
   a <- 1
@@ -17,7 +17,7 @@ x2drawspsm <- function(x, loss, nCores=0) {
     loss <- loss$loss
   }
   lossStr <- loss
-  if ( isPSM(x) ) {
+  if ( !forceNotPSM && isPSM(x) ) {
       psm <- x
       if ( lossStr == "binder" ) lossStr <- "binder.psm"
   } else {
