@@ -29,13 +29,18 @@
 #' @export
 #' @examples
 #' # For examples, use 'nCores=1' per CRAN rules, but in practice omit this.
+#' data(iris.clusterings)
 #' draws <- iris.clusterings
+#' # R_CARGO \dontrun{
+#' # R_CARGO # Example disabled since Cargo was not found when installing from source package.
+#' # R_CARGO # You can still run the example if you install Cargo. Hint: cargo::install().
 #' est <- salso(draws, nCores=1)
 #' summ <- summary(est)
 #' plot(summ, type="heatmap")
 #' plot(summ, type="mds")
 #' plot(summ, type="pairs", data=iris)
 #' plot(summ, type="dendrogram")
+#' # R_CARGO }
 #'
 summary.salso.estimate <- function(object, alternative, orderingMethod=1, ...) {
   estimate <- as.vector(if ( ! missing(alternative) ) alternative else object)
@@ -56,7 +61,7 @@ summary.salso.estimate <- function(object, alternative, orderingMethod=1, ...) {
   score <- sapply(one2n, function(i) {
     subset <- ( estimate == estimate[i] ) & ( one2n != i )
     xi <- if ( isPSM ) x[subset, subset, drop=FALSE] else x[, subset, drop=FALSE]
-    partition.loss(rep(1,ncol(xi)), xi, loss)
+    partition.loss(xi, rep(1,ncol(xi)), loss)
   })
   score[is.na(score)] <- 0
   # meanPS
@@ -91,7 +96,14 @@ summary.salso.estimate <- function(object, alternative, orderingMethod=1, ...) {
   m <- matrix(0.0, nrow=nClusters, ncol=nClusters)
   for ( i in seq_len(nClusters) ) {
     for ( j in seq_len(i) ) {
-      m[i,j] <- mean(psm[estimate==i, estimate==j])
+      m[i,j] <- if ( i == j ) local({
+        y <- estimate == i
+        x <- psm[y, y, drop=FALSE]
+        diag(x) <- 0
+        sum(x) / ( length(x) - sum(y) )
+      }) else {
+        mean(psm[estimate==i, estimate==j])
+      }
     }
   }
   ut <- upper.tri(m)
